==> html-components-0.1.0.tgz: package/src/__editor__/Div.tsx <==
import { createEditor, PluginParams } from '@modern-js-block/runtime';
import Div from '@/Div';

createEditor(Div, ({ ControlType, addPropertyControls }: PluginParams) => {
  addPropertyControls({
    // compClassName: {
    //   title: '类名',
    //   type: ControlType.CompClassName,
    //   tips: '组件必须接收className属性才会生效',
    //   disableLink: true,
    // },
    // customLessStyleCode: {
    //   title: '自定义样式',
    //   type: ControlType.LessCodeEditor,
    //   tips: '组件必须接收className属性才会生效',
    //   disableLink: true,
    // },
    style: {
      type: ControlType.Style,
      useStylePanel: true,
      title: '样式',
    },
    children: {
      type: ControlType.Slot,
      title: '内容',
    },
    onLoad: {
      type: ControlType.Action,
      title: '加载事件',
    },
    onClick: {
      type: ControlType.Action,
      title: '点击事件',
    },
    onDoubleClick: {
      type: ControlType.Action,
      title: '双击事件',
    },
    onMouseDown: {
      type: ControlType.Action,
      title: '鼠标按下事件',
    },
    onMouseMove: {
      type: ControlType.Action,
      title: '鼠标移动事件',
    },
    onMouseUp: {
      type: ControlType.Action,
      title: '鼠标抬起事件',
    },
    onMouseEnter: {
      type: ControlType.Action,
      title: '鼠标进入事件',
    },
    onMouseOut: {
      type: ControlType.Action,
      title: '鼠标移出事件',
    },
    onMouseLeave: {
      type: ControlType.Action,
      title: '鼠标离开事件',
    },
    onMouseOver: {
      type: ControlType.Action,
      title: '鼠标经过事件',
    },
    onKeyDown: {
      type: ControlType.Action,
      title: '键盘按下事件',
    },
    onKeyUp: {
      type: ControlType.Action,
      title: '鼠标抬起事件',
    },
    onKeyPress: {
      type: ControlType.Action,
      title: '鼠标按压事件',
    },
  });
});

==> html-components-0.1.1.tgz: package/src/__editor__/Div.tsx <==
import { createEditor, PluginParams } from '@modern-js-block/runtime';
import Div from '@/Div';

createEditor(Div, ({ ControlType, addPropertyControls }: PluginParams) => {
  addPropertyControls({
    compClassName: {
      title: 'className 类名',
      type: ControlType.CompClassName,
      tips: '给组件添加类名',
      disableLink: true,
    },
    customLessStyleCode: {
      title: '自定义 Less 样式',
      type: ControlType.LessCodeEditor,
      tips: '优先级高于 style 样式，可以写嵌套结构',
      disableLink: true,
    },
    style: {
      type: ControlType.Style,
      useStylePanel: true,
      title: '样式',
    },
    children: {
      type: ControlType.Slot,
      title: '内容',
    },
    onLoad: {
      type: ControlType.Action,
      title: '加载事件',
    },
    onClick: {
      type: ControlType.Action,
      title: '点击事件',
    },
    onDoubleClick: {
      type: ControlType.Action,
      title: '双击事件',
    },
    onMouseDown: {
      type: ControlType.Action,
      title: '鼠标按下事件',
    },
    onMouseMove: {
      type: ControlType.Action,
      title: '鼠标移动事件',
    },
    onMouseUp: {
      type: ControlType.Action,
      title: '鼠标抬起事件',
    },
    onMouseEnter: {
      type: ControlType.Action,
      title: '鼠标进入事件',
    },
    onMouseOut: {
      type: ControlType.Action,
      title: '鼠标移出事件',
    },
    onMouseLeave: {
      type: ControlType.Action,
      title: '鼠标离开事件',
    },
    onMouseOver: {
      type: ControlType.Action,
      title: '鼠标经过事件',
    },
    onKeyDown: {
      type: ControlType.Action,
      title: '键盘按下事件',
    },
    onKeyUp: {
      type: ControlType.Action,
      title: '鼠标抬起事件',
    },
    onKeyPress: {
      type: ControlType.Action,
      title: '鼠标按压事件',
    },
  });
});
